@@ -43,7 +43,7 @@
 #include <e2k-utils.h>
 
 #include <e-util/e-dialog-utils.h>
-#include <e-util/e-error.h>
+#include <e-util/e-alert-dialog.h>
 
 typedef struct {
 	const gchar *uri;
@@ -213,7 +213,7 @@ get_folder_security (ExchangeDelegates *delegates)
 		return delegates->loaded_folders;
 
 	if (!exchange_account_get_global_catalog (delegates->account)) {
-		e_error_run (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":delegates-no-gcs-error",
+		e_alert_run_dialog_for_args (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":delegates-no-gcs-error",
 			     NULL);
 		return FALSE;
 	}
@@ -252,14 +252,14 @@ get_folder_security (ExchangeDelegates *delegates)
 	status = e2k_result_iter_free (iter);
 
 	if (!E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
-		e_error_run (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":delegates-perm-read-error",
+		e_alert_run_dialog_for_args (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":delegates-perm-read-error",
 			     NULL);
 		return FALSE;
 	}
 
 	if (!fill_in_sids (delegates)) {
 		delegates->loaded_folders = FALSE;
-		e_error_run (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":perm-deter-error", NULL);
+		e_alert_run_dialog_for_args (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":perm-deter-error", NULL);
 		return FALSE;
 	}
 
@@ -425,7 +425,7 @@ add_button_clicked_cb (GtkWidget *widget, gpointer data)
 	user = exchange_delegates_user_new_from_gc (gc, email,
 						    delegates->creator_entryid);
 	if (!user) {
-		e_error_run (GTK_WINDOW (parent_window), ERROR_DOMAIN ":delegate-error", email, NULL);
+		e_alert_run_dialog_for_args (GTK_WINDOW (parent_window), ERROR_DOMAIN ":delegate-error", email, NULL);
 		g_free (email);
 		return;
 	}
@@ -434,7 +434,7 @@ add_button_clicked_cb (GtkWidget *widget, gpointer data)
 	delegate_exchange_dn = e2k_entryid_to_dn (user->entryid);
 	if (delegate_exchange_dn && !g_ascii_strcasecmp (delegate_exchange_dn, delegates->account->legacy_exchange_dn)) {
 		g_object_unref (user);
-		e_error_run (GTK_WINDOW (parent_window), ERROR_DOMAIN ":delegate-own-error", NULL);
+		e_alert_run_dialog_for_args (GTK_WINDOW (parent_window), ERROR_DOMAIN ":delegate-own-error", NULL);
 		return;
 	}
 
@@ -442,7 +442,7 @@ add_button_clicked_cb (GtkWidget *widget, gpointer data)
 		match = delegates->users->pdata[u];
 		if (e2k_sid_binary_sid_equal (e2k_sid_get_binary_sid (user->sid),
 					      e2k_sid_get_binary_sid (match->sid))) {
-			e_error_run (GTK_WINDOW (parent_window), ERROR_DOMAIN ":delegate-existing",
+			e_alert_run_dialog_for_args (GTK_WINDOW (parent_window), ERROR_DOMAIN ":delegate-existing",
 				     user->display_name, NULL);
 			g_object_unref (user);
 			exchange_delegates_user_edit (delegates->account, match, parent_window);
@@ -822,7 +822,7 @@ delegates_apply (ExchangeDelegates *delegates)
 
  done:
 	if (error) {
-		e_error_run (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":delegate-fail-error", error, NULL);
+		e_alert_run_dialog_for_args (GTK_WINDOW (delegates->table), ERROR_DOMAIN ":delegate-fail-error", error, NULL);
 		g_free (error);
 	}
 }
